@@ -1,15 +1,18 @@
 import asyncio
+import types
 from functools import partial
 import os
 import sys
 import threading
 import warnings
 
+import pkg_resources
 import pytest
 
 from tornado import ioloop, locks, queues
 from tornado.concurrent import Future
 
+import distributed
 from distributed.metrics import time
 from distributed.utils import get_ip, get_ipv6
 from distributed.utils_test import (
@@ -23,7 +26,7 @@ from distributed.utils_test import loop  # noqa: F401
 
 from distributed.protocol import to_serialize, Serialized, serialize, deserialize
 
-from distributed.comm.registry import backends
+from distributed.comm.registry import backends, get_backend
 from distributed.comm import (
     tcp,
     inproc,
@@ -1154,3 +1157,28 @@ async def test_tls_adresses():
 async def test_inproc_adresses():
     a, b = await get_inproc_comm_pair()
     await check_addresses(a, b)
+
+
+def test_register_backend_entrypoint():
+    # Code adapted from pandas backend entry point testing
+    # https://github.com/pandas-dev/pandas/blob/2470690b9f0826a8feb426927694fa3500c3e8d2/pandas/tests/plotting/test_backend.py#L50-L76
+
+    dist = pkg_resources.get_distribution("distributed")
+    if dist.module_path not in distributed.__file__:
+        # We are running from a non-installed distributed, and this test is invalid
+        pytest.skip("Testing a non-installed distributed")
+
+    mod = types.ModuleType("dask_udp")
+    mod.UDPBackend = lambda: 1
+    sys.modules[mod.__name__] = mod
+
+    entry_point_name = "distributed.comm.backends"
+    backends_entry_map = pkg_resources.get_entry_map("distributed")
+    if entry_point_name not in backends_entry_map:
+        backends_entry_map[entry_point_name] = dict()
+    backends_entry_map[entry_point_name]["udp"] = pkg_resources.EntryPoint(
+        "udp", mod.__name__, attrs=["UDPBackend"], dist=dist
+    )
+
+    result = get_backend("udp")
+    assert result == 1
