@@ -1,5 +1,3 @@
-from __future__ import print_function, division, absolute_import
-
 import itertools
 from operator import mul
 import random
@@ -15,6 +13,7 @@ from distributed import Nanny, Worker, wait, worker_client
 from distributed.config import config
 from distributed.metrics import time
 from distributed.scheduler import key_split
+from distributed.system import MEMORY_LIMIT
 from distributed.utils_test import (
     slowinc,
     slowadd,
@@ -24,7 +23,6 @@ from distributed.utils_test import (
     captured_logger,
 )
 from distributed.utils_test import nodebug_setup_module, nodebug_teardown_module
-from distributed.worker import TOTAL_MEMORY
 
 import pytest
 
@@ -114,8 +112,8 @@ def test_worksteal_many_thieves(c, s, *workers):
 def test_dont_steal_unknown_functions(c, s, a, b):
     futures = c.map(inc, [1, 2], workers=a.address, allow_other_workers=True)
     yield wait(futures)
-    assert len(a.data) == 2
-    assert len(b.data) == 0
+    assert len(a.data) == 2, [len(a.data), len(b.data)]
+    assert len(b.data) == 0, [len(a.data), len(b.data)]
 
 
 @gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 2)
@@ -172,7 +170,7 @@ def test_new_worker_steals(c, s, a):
     while len(a.task_state) < 10:
         yield gen.sleep(0.01)
 
-    b = yield Worker(s.address, loop=s.loop, nthreads=1, memory_limit=TOTAL_MEMORY)
+    b = yield Worker(s.address, loop=s.loop, nthreads=1, memory_limit=MEMORY_LIMIT)
 
     result = yield total
     assert result == sum(map(inc, range(100)))
@@ -234,7 +232,7 @@ def test_dont_steal_host_restrictions(c, s, a, b):
     yield future
 
     futures = c.map(slowinc, range(100), delay=0.1, workers="127.0.0.1")
-    while len(a.task_state) < 10:
+    while len(a.task_state) + len(b.task_state) < 100:
         yield gen.sleep(0.01)
     assert len(a.task_state) == 100
     assert len(b.task_state) == 0
@@ -254,7 +252,7 @@ def test_dont_steal_resource_restrictions(c, s, a, b):
     yield future
 
     futures = c.map(slowinc, range(100), delay=0.1, resources={"A": 1})
-    while len(a.task_state) < 10:
+    while len(a.task_state) + len(b.task_state) < 100:
         yield gen.sleep(0.01)
     assert len(a.task_state) == 100
     assert len(b.task_state) == 0
@@ -319,12 +317,15 @@ def test_dont_steal_executing_tasks(c, s, a, b):
     assert len(b.data) == 0
 
 
-@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 10)
+@gen_cluster(
+    client=True,
+    nthreads=[("127.0.0.1", 1)] * 10,
+    config={"distributed.scheduler.default-task-durations": {"slowidentity": 0.2}},
+)
 def test_dont_steal_few_saturated_tasks_many_workers(c, s, a, *rest):
     s.extensions["stealing"]._pc.callback_time = 20
     x = c.submit(mul, b"0", 100000000, workers=a.address)  # 100 MB
     yield wait(x)
-    s.task_duration["slowidentity"] = 0.2
 
     futures = [c.submit(slowidentity, x, pure=False, delay=0.2) for i in range(2)]
 
@@ -337,13 +338,13 @@ def test_dont_steal_few_saturated_tasks_many_workers(c, s, a, *rest):
 @gen_cluster(
     client=True,
     nthreads=[("127.0.0.1", 1)] * 10,
-    worker_kwargs={"memory_limit": TOTAL_MEMORY},
+    worker_kwargs={"memory_limit": MEMORY_LIMIT},
+    config={"distributed.scheduler.default-task-durations": {"slowidentity": 0.2}},
 )
 def test_steal_when_more_tasks(c, s, a, *rest):
     s.extensions["stealing"]._pc.callback_time = 20
     x = c.submit(mul, b"0", 50000000, workers=a.address)  # 50 MB
     yield wait(x)
-    s.task_duration["slowidentity"] = 0.2
 
     futures = [c.submit(slowidentity, x, pure=False, delay=0.2) for i in range(20)]
 
@@ -353,7 +354,16 @@ def test_steal_when_more_tasks(c, s, a, *rest):
         assert time() < start + 1
 
 
-@gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 10)
+@gen_cluster(
+    client=True,
+    nthreads=[("127.0.0.1", 1)] * 10,
+    config={
+        "distributed.scheduler.default-task-durations": {
+            "slowidentity": 0.2,
+            "slow2": 1,
+        }
+    },
+)
 def test_steal_more_attractive_tasks(c, s, a, *rest):
     def slow2(x):
         sleep(1)
@@ -363,9 +373,6 @@ def test_steal_more_attractive_tasks(c, s, a, *rest):
     x = c.submit(mul, b"0", 100000000, workers=a.address)  # 100 MB
     yield wait(x)
 
-    s.task_duration["slowidentity"] = 0.2
-    s.task_duration["slow2"] = 1
-
     futures = [c.submit(slowidentity, x, pure=False, delay=0.2) for i in range(10)]
     future = c.submit(slow2, x, priority=-1)
 
@@ -401,7 +408,6 @@ def assert_balanced(inp, expected, c, s, *workers):
                     ws.nbytes += ts.nbytes - old_nbytes
             else:
                 dat = 123
-            s.task_duration[str(int(t))] = 1
             i = next(counter)
             f = c.submit(
                 func,
@@ -475,7 +481,15 @@ def assert_balanced(inp, expected, c, s, *workers):
 )
 def test_balance(inp, expected):
     test = lambda *args, **kwargs: assert_balanced(inp, expected, *args, **kwargs)
-    test = gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * len(inp))(test)
+    test = gen_cluster(
+        client=True,
+        nthreads=[("127.0.0.1", 1)] * len(inp),
+        config={
+            "distributed.scheduler.default-task-durations": {
+                str(i): 1 for i in range(10)
+            }
+        },
+    )(test)
     test()
 
 
@@ -497,10 +511,12 @@ def test_restart(c, s, a, b):
     assert not any(x for L in steal.stealable.values() for x in L)
 
 
-@gen_cluster(client=True)
+@gen_cluster(
+    client=True,
+    config={"distributed.scheduler.default-task-durations": {"slowadd": 0.001}},
+)
 def test_steal_communication_heavy_tasks(c, s, a, b):
     steal = s.extensions["stealing"]
-    s.task_duration["slowadd"] = 0.001
     x = c.submit(mul, b"0", int(s.bandwidth), workers=a.address)
     y = c.submit(mul, b"1", int(s.bandwidth), workers=b.address)
 
